@@ -18,11 +18,11 @@ Log::Abstraction - Logging Abstraction Layer
 
 =head1 VERSION
 
-0.22
+0.23
 
 =cut
 
-our $VERSION = 0.22;
+our $VERSION = 0.23;
 
 =head1 SYNOPSIS
 
@@ -295,7 +295,7 @@ sub _log
 			# The test is because Log::Log4perl doesn't understand notice()
 			$logger->$level(@messages);
 		} else {
-			croak(ref($self), ": Don't know how to deal with the $level message");
+			croak(ref($self), ': ', ref($logger), " doesn't know how to deal with the $level message");
 		}
 	} elsif($self->{'array'}) {
 		push @{$self->{'array'}}, { level => $level, message => join('', @messages) };
@@ -489,20 +489,26 @@ sub _high_priority
 	# Log the warning message
 	$self->_log($level, $warning);
 
-	if($self->{syslog}) {
+	if($self->{'syslog'}) {
 		# Handle syslog-based logging
 		if(ref($self->{syslog}) eq 'HASH') {
-			# HASH argument to setlogsocket introduced in Sys::Syslog 0.28
+			# HASH argument to setlogsock introduced in Sys::Syslog 0.28
+
+			# CHI uses server, Sys::Syslog uses host :-(
+			if($self->{'syslog'}->{'server'}) {
+				$self->{'syslog'}->{'host'} = delete $self->{'syslog'}->{'server'};
+			}
 			Sys::Syslog::setlogsock($self->{'syslog'});
 		}
+		my $ident = (($level eq 'error') ? 'err' : 'warning') . '|local0';
 		openlog($self->{script_name}, 'cons,pid', 'user');
 		eval {
-			my $ident = ($level eq 'error') ? 'err' : 'warning';
-			syslog("$ident|local0", $warning);
+			syslog($ident, $warning);
 		};
 		my $err = $@;
 		closelog();
 		if($err) {
+			$err .= ": \n" . Data::Dumper->new([$self->{'syslog'}])->Dump();
 			Carp::carp($err);
 		} elsif($self->{'carp_on_warn'}) {
 			Carp::carp($warning);
